@@ -1212,7 +1212,6 @@ def marriage(img: BuildImage = UserImg(), arg=NoArg()):
         img_w = 1500
     elif img_w < 800:
         img_h = int(img_h * img_w / 800)
-        img_w = 800
     frame = img.resize_canvas((img_w, img_h)).resize_height(1080)
     left = load_image("marriage/0.png")
     right = load_image("marriage/1.png")
@@ -1220,3 +1219,10 @@ def marriage(img: BuildImage = UserImg(), arg=NoArg()):
         right, (frame.width - right.width, 0), alpha=True
     )
     return frame.save_jpg()
+
+
+def painter(img: BuildImage = UserImg(), arg=NoArg()):
+    img = img.convert("RGBA").resize((240, 345), keep_ratio=True)
+    frame = load_image("painter/0.png")
+    frame.paste(img, (125, 91), below=True)
+    return frame.save_jpg()
